calculate.orbit.counts calculates the orbit counts of the current network.
calculate.orbit.counts(network)An N-by-73 matrix, with N the number of nodes in the network and 1 column for each possible orbit.
The value of mat[i,j] is the number of times node i has orbit j in a subgraph in the network.
An instance of the incgraph.network class
The complete orbit counts is calcucated using the orca::count5().
Calling this method repeatedly becomes very inefficient for evolving networks. For evolving networks, the usage
of calculate.delta() is recommended.
For more details on this method, see Hočevar and Demšar (2014).
Hočevar, T. and Demšar J. (2014) A combinatorial approach to graphlet counting. Bioinformatics.
See new.incgraph.network() for examples and usage.