calculate.delta calculates the changes in orbit counts as a result of a single edge modification.
calculate.delta(network, i, j)A list containing two N-by-73 matrices, with N the number of nodes in the network and 1 column for each possible orbit.
The value of list$add[i,j] (resp. list$rem[i,j]) is the number of times a subgraph was added to (resp. removed from)
the network such that node i has orbit j in that subgraph.
An instance of the incgraph.network class
A node in network
A node in network
This method iterates over and counts all graphlets which were added to or removed from the network due to one edge modification.
Cannoodt, R. et al. (2015) IncGraph: A graphlet-based approach for characterising topological changes in evolving networks. Submitted to Bioinformatics.
See new.incgraph.network() for examples and usage.